-----------------------------------------------------------------------------------------
-- Author : Luiz Henrique Lugato
-- Date : 25/01/2021
--
-- main.lua
--
-----------------------------------------------------------------------------------------


--##############################################################################
--# print Function to show table structues like PHP ptint_r
--##############################################################################
local function print_r ( t )
        local print_r_cache={}
        local function sub_print_r(t,indent)
                if (print_r_cache[tostring(t)]) then
                        print(indent.."*"..tostring(t))
                else
                        print_r_cache[tostring(t)]=true
                        if (type(t)=="table") then
                                for pos,val in pairs(t) do
                                        if (type(val)=="table") then
                                                print(indent.."["..pos.."] => "..tostring(t).." {")
                                                sub_print_r(val,indent..string.rep(" ",string.len(pos)+8))
                                                print(indent..string.rep(" ",string.len(pos)+6).."}")
                                        elseif (type(val)=="string") then
                                                print(indent.."["..pos..'] => "'..val..'"')
                                        else
                                                print(indent.."["..pos.."] => "..tostring(val))
                                        end
                                end
                        else
                                print(indent..tostring(t))
                        end
                end
        end
        if (type(t)=="table") then
                print(tostring(t).." {")
                sub_print_r(t,"  ")
                print("}")
        else
                sub_print_r(t,"  ")
        end
        print()
end


--##############################################################################
--# Admob variables
--##############################################################################
admob = require( "plugin.admob" )
admob_adUnitId        = "ca-app-pub-19XX10XX747XX480/1647XX0400" -- Put your adUnitId here !!
admob_childSafe       = true
admob_hasUserConsent  = false
admob_initialized     = false
admob_testmode        = true


--##############################################################################
--# Variables
--##############################################################################
local btAdmobShowBanner
local txtAdmobShowBanner
local btAdmobStatus
local btAdmobHideBanner
local txtAdmobHideBanner

local btUnityShowInterstitial
local txtUnityShowInterstitial
local btUnityStatus

local boxHelp
local HelpColorInit
local txtHelpColorInit
local HelpColorLoad
local txtHelpColorLoad
local HelpColorShow
local txtHelpColorShow
local HelpColorFail
local txtHelpColorFail
local HelpColorLoadFail
local txtHelpColorLoadFail

local txtHelpStatusInit
local txtHelpStatusLoad
local txtHelpStatusShow
local txtHelpStatusFail
local txtHelpStatusLoadFail




--##############################################################################
--# Admob Listner
--##############################################################################
function admobAdsListener( event )
    print("============ [ ADMOB EVENT ] ======================================")
    print_r( event )
    print("===================================================================")
    if (event.isError) then
      print ("AdMob error: "..event.response.." : "..event.data);
    end

    if ( event.phase == "init" ) then  -- Successful initialization
      print ("############ Banner Initialized ###################");
      local tableParameters = {adUnitId=admob_adUnitId, childSafe=admob_childSafe, hasUserConsent=admob_hasUserConsent}

print_r(tableParameters)

      admob.load( "banner", tableParameters)
      admob_initialized = true
      btAdmobStatus:setFillColor(0/255, 0/255, 255/255)
      txtHelpStatusInit.isVisible = true
    end

    if (event.phase == "loaded") then
      print ("############ Banner Loaded #######################");
      btAdmobStatus:setFillColor(229/255, 61/255, 235/255)
      txtHelpStatusLoad.isVisible = true
      txtHelpStatusLoadFail.isVisible = false
    end

    if (event.phase == "displayed") then
      print ("############ Banner displayed ####################");
      btAdmobStatus:setFillColor(235/255, 235/255, 61/255)
    end

    if (event.phase == "hidden") then
      print ("############ Banner hidden #######################");
    end

    if ( event.phase == "failed" ) then  -- Successful initialization
      print("############ ADMOB EVENT - FAILED #################")
    end
end


--##############################################################################
--# Admob Show Banner
--##############################################################################
local function AdmobShowBanner( event )
  if event.phase == "ended" then
    if admob_initialized then
      print("############### AdMob was initialized ################")
    else
      print("############### AdMob not initialized ################")
      btAdmobStatus:setFillColor(255/255, 0/255, 0/255)
      txtHelpStatusFail.isVisible = true
    end
    if ( admob.isLoaded( "banner" ) ) then
        tableParameterShow = {y="top"}
        admob.show( "banner",tableParameterShow)
        txtHelpStatusShow.isVisible = true
    else
      print("############### AdMob banner not loaded ################")
      btAdmobStatus:setFillColor(255/255,140/255,0/255)
      txtHelpStatusFail.isVisible = true
    end
  end
end

--##############################################################################
--# Admob Hide Banner
--##############################################################################
local function AdmobHideBanner( event )
  if event.phase == "ended" then
    admob.hide()
    if admob_initialized then
      btAdmobStatus:setFillColor(229/255, 61/255, 235/255)
      txtHelpStatusShow.isVisible = false
    else
      btAdmobStatus:setFillColor(255/255, 0/255, 0/255)
      txtHelpStatusFail.isVisible = true
    end
  end
end


--##############################################################################
--# Admob Initialize
--##############################################################################
admob.init( admobAdsListener, { testMode=admob_testmode } )


--##############################################################################
--# Admob Bottons and Status rect
--##############################################################################
btAdmobShowBanner = display.newRect(160, 100, 200, 50)
btAdmobShowBanner:addEventListener( "touch", AdmobShowBanner )
btAdmobShowBanner:setFillColor(205/255, 173/255, 149/255)

btAdmobStatus = display.newRect(btAdmobShowBanner.x+110, btAdmobShowBanner.y, 10, 50)
btAdmobStatus:setFillColor(255/255, 0/255, 0/255)

txtAdmobShowBanner = display.newText("AdMob Show Banner", btAdmobShowBanner.x, btAdmobShowBanner.y, native.systemFont, 20)

btAdmobHideBanner = display.newRect(btAdmobShowBanner.x, btAdmobShowBanner.y + 70, 200, 50)
btAdmobHideBanner:addEventListener( "touch", AdmobHideBanner )
btAdmobHideBanner:setFillColor(205/255, 173/255, 149/255)
txtAdmobHideBanner = display.newText("AdMob Hide Banner", btAdmobHideBanner.x, btAdmobHideBanner.y, native.systemFont, 20)



--##############################################################################
--# Box help for admob status
--##############################################################################
boxHelp = display.newRect(160, 320, 250,150)

HelpColorInit = display.newRect(boxHelp.x-110, boxHelp.y-60, 10,20)
HelpColorInit:setFillColor(0/255, 0/255, 255/255)
txtHelpStatusInit = display.newText(".", HelpColorInit.x, HelpColorInit.y-15, native.systemFont, 50)
txtHelpStatusInit.isVisible = false
txtHelpColorInit = display.newText("Initalized", HelpColorInit.x+50, HelpColorInit.y, native.systemFont, 20)
txtHelpColorInit:setFillColor(0)

HelpColorLoad = display.newRect(HelpColorInit.x, HelpColorInit.y+30, 10,20)
HelpColorLoad:setFillColor(229/255, 61/255, 235/255)
txtHelpStatusLoad = display.newText(".", HelpColorLoad.x, HelpColorLoad.y-15, native.systemFont, 50)
txtHelpStatusLoad.isVisible = false
txtHelpColorLoad = display.newText("Loaded", HelpColorLoad.x+45, HelpColorLoad.y, native.systemFont, 20)
txtHelpColorLoad:setFillColor(0)

HelpColorShow = display.newRect(HelpColorLoad.x, HelpColorLoad.y+30, 10,20)
HelpColorShow:setFillColor(235/255, 235/255, 61/255)
txtHelpStatusShow = display.newText(".", HelpColorShow.x, HelpColorShow.y-15, native.systemFont, 50)
txtHelpStatusShow.isVisible = false
txtHelpColorShow = display.newText("Displayed", HelpColorShow.x+55, HelpColorShow.y, native.systemFont, 20)
txtHelpColorShow:setFillColor(0)

HelpColorFail = display.newRect(HelpColorShow.x, HelpColorShow.y+30, 10,20)
HelpColorFail:setFillColor(255/255, 0/255, 0/255)
txtHelpStatusFail = display.newText(".", HelpColorFail.x, HelpColorFail.y-15, native.systemFont, 50)
txtHelpStatusFail.isVisible = false
txtHelpColorFail = display.newText("Error", HelpColorFail.x+34, HelpColorFail.y, native.systemFont, 20)
txtHelpColorFail:setFillColor(0)

HelpColorLoadFail = display.newRect(HelpColorFail.x, HelpColorFail.y+30, 10,20)
HelpColorLoadFail:setFillColor(255/255,140/255,0/255)
txtHelpStatusLoadFail = display.newText(".", HelpColorLoadFail.x, HelpColorLoadFail.y-15, native.systemFont, 50)
txtHelpStatusLoadFail.isVisible = true
txtHelpColorLoadFail = display.newText("Load banner failed", HelpColorLoadFail.x+90, HelpColorLoadFail.y, native.systemFont, 20)
txtHelpColorLoadFail:setFillColor(0)
